pub struct BlockData {
pub slot: u64,
pub blockhash: String,
pub parent_slot: u64,
pub parent_blockhash: String,
pub block_time: Option<i64>,
pub block_height: Option<u64>,
pub transaction_count: u64,
pub raw: Value,
}Expand description
Block-level data passed to Plugin::on_block.
Contains both extracted fields and the full raw JSON response so plugins can access any field the framework doesn’t extract.
Fields
slot: u64blockhash: Stringparent_slot: u64parent_blockhash: Stringblock_time: Option<i64>block_height: Option<u64>transaction_count: u64raw: ValueTrait Implementations
Sourceimpl<'de> Deserialize<'de> for BlockData
impl<'de> Deserialize<'de> for BlockData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more