Stdout plugin โ prints block data as JSON lines to stdout.
Useful for piping to jq, grep, or other CLI tools.
Structs
- Stdout
Plugin - Built-in plugin that prints block data to stdout as one JSON line per block.
Stdout plugin โ prints block data as JSON lines to stdout.
Useful for piping to jq, grep, or other CLI tools.